<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\WaterQualityIlr;
use Modules\Qc\Entities\WaterQualityIlrAttachment;

class WaterQualityIlrController extends Controller
{
    public function uploadAttachment(Request $request)
    {
        try {
            $token = $request->get('attachment_token');
            $file = $request->file('file');
            $file_name = $file->getClientOriginalName();
            $filename = uniqid() . '_' . time() . '.' . $file_name;
            $file->move(public_path('water_quality'), $filename);

            $water_quality_attachment = new WaterQualityIlrAttachment();
            $water_quality_attachment->water_quality_id = 0;
            $water_quality_attachment->path = $filename;
            $water_quality_attachment->token = $token;
            $water_quality_attachment->save();

            $responseBody = $this->responseBody(true, "WaterQualityIlrController", "uploaded", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function allRecords()
    {
        try {
            $query = "SELECT
            qc_water_quality_ilrs.*,
            qc_water_quality_ilr_attachments.path,
            pp_customer_order_plans_data.manufacturing_order_no,
            st_products.product_name,
            hr_employee_sites.site
        FROM
            qc_water_quality_ilr_attachments
            INNER JOIN
            qc_water_quality_ilrs
            ON
                qc_water_quality_ilr_attachments.water_quality_id = qc_water_quality_ilrs.water_quality_id
            INNER JOIN
            pp_customer_order_plans_data
            ON
                qc_water_quality_ilrs.customer_order_plan_data_id = pp_customer_order_plans_data.customer_order_plan_data_id
            INNER JOIN
            st_products
            ON
                pp_customer_order_plans_data.product_id = st_products.product_primary_id
            INNER JOIN
            hr_employee_sites
            ON
                qc_water_quality_ilrs.factory = hr_employee_sites.site_id
                GROUP BY
            qc_water_quality_ilrs.water_quality_id
            ";

            $records = DB::select($query);
            $result = array();
            foreach ($records as $record) {
                array_push($result, [
                    "water_quality_id" => $record->water_quality_id,
                    "reference_no" => $record->reference_no,
                    "product_name" => $record->product_name,
                    "manufacturing_order_no" => $record->manufacturing_order_no,
                    "date" => $record->date,
                    "factory" => $record->site,
                    "description" => $record->description,
                    "path" => $record->path,
                ]);
            }
            $responseBody = $this->responseBody(true, "WaterQualityIlrController", "allRecords", $result);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function saveRecord(Request $request)
    {
        try {
            $wq = new WaterQualityIlr();
            $wq->user_id = Auth::user()->id;
            $wq->reference_no = $request->get('reference_no');
            $wq->date = $request->get('date');
            $wq->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $wq->factory = $request->get('factory');
            $wq->description = $request->get('description');
            if ($wq->save()) {
                $token = $request->get('attachment_token');
                $attachment = WaterQualityIlrAttachment::where('token', '=', $token)->first();
                if ($attachment) {
                    $attachment->water_quality_id = $wq->water_quality_id;
                    $attachment->update();
                }
            }
            $responseBody = $this->responseBody(true, "WaterQualityIlrController", "saveRecord", $attachment);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    public function update(Request $request, $id)
    {
        try {
            $wq = WaterQualityIlr::find($id);
            $wq->user_id = Auth::user()->id;
            $wq->reference_no = $request->get('reference_no');
            $wq->date = $request->get('date');
            $wq->customer_order_plan_data_id = $request->get('customer_order_plan_data_id');
            $wq->factory = $request->get('factory');
            $wq->description = $request->get('description');
            if ($wq->update()) {
                $token = $request->get('attachment_token');
                $attachments = WaterQualityIlrAttachment::where('token', '=', $token)->get();
                if (count($attachments) > 1) {
                    if ($this->delete($id)) {
                        $attachment = WaterQualityIlrAttachment::where('token', '=', $token)->first();
                        $attachment->water_quality_id = (int)$id;
                        $attachment->update();
                    }
                }
                $responseBody = $this->responseBody(true, "WaterQualityIlrController", "updated", count($attachments));
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }




    public function delete($id)
    {
        try {
            $attachment = WaterQualityIlrAttachment::where('water_quality_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            return true;
        } catch (Exception $exception) {
            return false;
        }
    }


    public function deleteRecord($id)
    {
        try {
            $record = WaterQualityIlr::where('water_quality_id', '=', $id)->get();
            foreach ($record as $data) {
                $data->delete();
            }
            $attachment = WaterQualityIlrAttachment::where('water_quality_id', '=', $id)->get();
            foreach ($attachment as $data) {
                $data->delete();
            }
            $responseBody = $this->responseBody(true, "WaterQualityIlrController", "deleted", null);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    public function getData($id)
    {
        try {
            $query = "SELECT
            qc_water_quality_ilrs.*,
            qc_water_quality_ilr_attachments.token
        FROM
            qc_water_quality_ilr_attachments
            INNER JOIN
            qc_water_quality_ilrs
            ON
                qc_water_quality_ilr_attachments.water_quality_id = qc_water_quality_ilrs.water_quality_id
        WHERE
            qc_water_quality_ilrs.water_quality_id = {$id}";

            $wq =  DB::select($query);

            $responseBody = $this->responseBody(true, "WaterQualityIlrController", "getData", $wq[0]);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "WaterQualityIlrController", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }
}
