$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Factory" },
            { data: "Supplier Name" },
            { data: "Inspection Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 4 },
            { width: 30, targets: 5 },
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
        ],
    });

    allPmRecords();
});

function allPmRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/PackingMaterialChecklistHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {},
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no = response.data.result[i]["reference_no"];
                    var factory = response.data.result[i]["factory"];
                    var supplier_name = response.data.result[i]["supplier_name"];
                    var date = response.data.result[i]["date"];
                    var scl_id = response.data.result[i]["scl_id"];
                    data.push({
                        "Reference No": reference_no,
                        Factory: factory,
                        "Supplier Name": supplier_name,
                        "Inspection Date": date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            scl_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            scl_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            scl_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            scl_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () {},
    });
}

function edit(id) {
    location.href = "/qc/packingMaterial?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/packingMaterial?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/PackingMaterialChecklistHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allPmRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

// function print(id) {
//     $.ajax({
//         type: "GET",
//         url:
//             "/qc/PackingMaterialChecklistHeaderController/supervisorCheckListReport/" +
//             id,
//         processData: false,
//         contentType: false,
//         cache: false,
//         timeout: 800000,
//         beforeSend: function () {},
//         success: function (response) {
//             console.log(response);
//             var result = response.data.result;
//             console.log(result);
//             supervisorCheckingPrint(result, "PRINT");
//         },
//         error: function (error) {
//             console.log(error);
//             showErrorMessage();
//         },
//         complete: function () {

//         },
//     });
// }

// function supervisorCheckingPrint(result, flag) {
//     var headerFontSize = 8;
//     var Title = [{ text: "" }];

//     var header_data = result.header;

//     var Header = [
//         {
//             content: [
//                 {
//                     table: {
//                         widths: ["*"],
//                         headerRows: 1,
//                         body: [
//                             [
//                                 {
//                                     text: Page.getReportName(),
//                                     fontSize: 16,
//                                     bold: true,
//                                     alignment: "center",
//                                     border: [false, false, false, false],
//                                 },
//                             ],
//                             [
//                                 {
//                                     text: "Packing Line Quality Records",
//                                     fontSize: 14,
//                                     bold: true,
//                                     alignment: "center",
//                                     border: [false, false, false, false],
//                                 },
//                             ],
//                             [
//                                 {
//                                     table: {
//                                         widths: ["*", 150],
//                                         headerRows: 1,
//                                         body: [
//                                             [
//                                                 {
//                                                     text:
//                                                         "Order No : " +
//                                                         header_data.order_no,
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "left",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                                 {
//                                                     text:
//                                                         "Product : " +
//                                                         header_data.product,
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "right",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                             ],
//                                             [
//                                                 {
//                                                     text: "",
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "left",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                                 {
//                                                     text:
//                                                         "Factory Order Number : " +
//                                                         header_data.factory_order_number,
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "right",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                             ],
//                                             [
//                                                 {
//                                                     text: "",
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "left",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                                 {
//                                                     text:
//                                                         "Date & Time : " +
//                                                         header_data.trans_date,
//                                                     fontSize: 9,
//                                                     bold: false,
//                                                     alignment: "right",
//                                                     border: [
//                                                         false,
//                                                         false,
//                                                         false,
//                                                         false,
//                                                     ],
//                                                 },
//                                             ],
//                                         ],
//                                     },
//                                     border: [false, false, false, false],
//                                 },
//                             ],
//                         ],
//                     },
//                     margin: [0, 0],
//                 },
//             ],
//         },
//     ];

//     var footer_data = result.header;
//     var Body = [
//         {
//             table: {
//                 widths: ["*", "*", "*", "*", "*", "*", "*", "*", "*", "*", "*"],
//                 headerRows: 1,
//                 body: packingLineQualityPrint(result.body),
//             },
//         },
//         {
//             table: {
//                 widths: ["*"],
//                 headerRows: 1,
//                 body: [
//                     [
//                         {
//                             text: "SLD - Slab Damage, PRD - Print Damage, PAD - Packing Damage, S Length - Sealing Length",
//                             fontSize: 7,
//                             margin: [0, 15, 0, 0],
//                             color: "gray",
//                             bold: false,
//                             alignment: "left",
//                             border: [false, false, false, false],
//                         },
//                     ],
//                 ],
//             },
//             border: [false, false, false, false],
//         },
//     ];

//     var Footer = [
//         {
//             color: "red",
//             fontSize: 8,
//             alignment: "center",
//             margin: [0, 0],
//         },
//     ];

//     var page = new Page();
//     page.setPageSize("A4");
//     page.setPageOrientation("landscape");
//     page.setPageMargin([10, 10, 10, 10]);
//     page.setTitle(Title);
//     page.setHeader(Header, Page.EVERY);
//     page.setBody(Body);
//     page.setFooter(Footer);
//     if (flag == "EXPORT") {
//         page.export();
//     } else if (flag == "PRINT") {
//         page.preview();
//     }
// }

// function packingLineQualityPrint(result) {
//     var font_size = 8;
//     var body = [];
//     body.push([
//         {
//             text: "Hours",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Sealer-1",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Sealer-2",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Sealer-3",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Sealer-4",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Sealer-5",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "SLD",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "PRD",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "PAD",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "S Length",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//         {
//             text: "Checked",
//             fontSize: font_size,
//             bold: true,
//             alignment: "center",
//             border: [true, true, true, true],
//         },
//     ]);

//     var data = result.data;
//     for (i = 0; i < data.length; i++) {
//         body.push([
//             {
//                 text: data[i].hour,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].seal_damage1,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].seal_damage2,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].seal_damage3,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].seal_damage4,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].seal_damage5,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].slab_damage,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].print_damage,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].packing_damage,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].sealing_length,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//             {
//                 text: data[i].name_withinitial,
//                 fontSize: font_size,
//                 alignment: "center",
//                 border: [true, true, true, true],
//             },
//         ]);
//     }

//     return body;
// }

/**
 * showSuccessMessage
 * This function is used to show success message.
 * @param message This is the paramter to require message content
 */
function showSuccessMessage(message) {
    toastr.success(message);
}

/**
 * showWarningMessage
 * This function is used to show warning message.
 * @param message This is the paramter to require message content
 */
function showWarningMessage(message) {
    toastr.warning(message);
}

/**
 * showErrorMessage
 * This function is used to show error message.
 * @param message This is the paramter to require message content
 */
function showErrorMessage() {
    toastr.error("Something went wrong");
}
